@@ -1,6 +1,6 @@
 /******************************************************************************
  *
- * $Id: gs_osishtmlhref.h,v 1.1 2004/02/12 13:59:45 tbiggs Exp $
+ * $Id: gs_osishtmlhref.h,v 1.3 2004/09/26 18:25:39 tbiggs Exp $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -27,13 +27,14 @@ SWORD_NAMESPACE_START
 
 /** this filter converts OSIS text to HTML text with hrefs
  */
-class SWDLLEXPORT GSOSISHTMLHREF : public SWBasicFilter {
+class SWDLLEXPORT GS_OSISHTMLHREF : public SWBasicFilter {
 private:
 protected:
 	class MyUserData : public BasicFilterUserData {
 	public:
 		bool osisQToTick;
 		bool inBold;
+		bool inRed;
 		SWBuf lastTransChange;
 		SWBuf w;
 		SWBuf fn;
@@ -45,7 +46,7 @@ protected:
 	}
 	virtual bool handleToken(SWBuf &buf, const char *token, BasicFilterUserData *userData);
 public:
-	GSOSISHTMLHREF();
+	GS_OSISHTMLHREF();
 };
 
 SWORD_NAMESPACE_END
