@@ -2,7 +2,7 @@
  * GnomeSword Bible Study Tool
  * bibletext.c - gui for Bible text modules
  *
- * Copyright (C) 2000,2001,2002,2003 GnomeSword Developer Team
+ * Copyright (C) 2000,2001,2002,2003,2004,2005 GnomeSword Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -25,16 +25,23 @@
 
 #include <gnome.h>
 #include <gtkhtml/gtkhtml.h>
-#include <gtkhtml/htmlengine.h>
 
 #ifdef USE_GTKMOZEMBED
 #include <gtkmozembed.h>
 #endif
 
 
+#ifdef USE_GTKHTML38
+#include "editor/html-editor.h"
+#else
+#include <gtkhtml/htmlengine.h>
+#include "editor/editor-control.h"
+#endif
+
 #include "gui/gnomesword.h"
 #include "gui/bibletext.h"
 #include "gui/bibletext_dialog.h"
+#include "gui/bookmark_dialog.h"
 #include "gui/bookmarks_treeview.h"
 #include "gui/shortcutbar_main.h"
 #include "gui/sidebar.h"
@@ -56,6 +63,7 @@
 #include "main/global_ops.hh"
 #include "main/embed.h"
 
+
 gboolean shift_key_presed = FALSE;
 
 static void create_menu(void); //GdkEventButton * event);
@@ -207,9 +215,15 @@ static gboolean on_text_button_release_event(GtkWidget * widget,
 		}
 		if (!in_url)
 			break;
+#ifdef USE_GTKHTML38
+		url = gtk_html_get_url_at (GTK_HTML(widgets.html_text),		
+								event->x,
+								event->y);
+#else
 		url = html_engine_get_link_at (GTK_HTML(widgets.html_text)->engine,
 					 event->x,
 					 event->y);
+#endif
 		if(strstr(url,"sword://")) {
 			gchar **work_buf = g_strsplit (url,"/",4);
 			gui_open_passage_in_new_tab(work_buf[3]);
@@ -288,7 +302,9 @@ static gboolean on_key_press_event           (GtkWidget       *widget,
 			shift_key_presed = TRUE;
 		break;
 	}
+#ifdef DEBUG
 	g_message("on_key_press_event");
+#endif
   	return FALSE;
 }
 
@@ -613,7 +629,11 @@ void on_item1_activate(GtkMenuItem * menuitem, gpointer user_data)
 
 void on_print1_activate(GtkMenuItem * menuitem, gpointer user_data)
 {
+#ifdef USE_GTKMOZEMBED
+	embed_print(TRUE, GTK_MOZ_EMBED(widgets.html_text));
+#else
 	gui_html_print(widgets.html_text, FALSE);
+#endif
 }
 
 
@@ -775,7 +795,11 @@ void gui_lookup_bibletext_selection(GtkMenuItem * menuitem,
 
 static void edit_percomm(GtkMenuItem * menuitem, gpointer user_data)
 {
+#ifdef USE_GTKHTML38
+	editor_create_new((gchar *)user_data,(gchar *)settings.currentverse,TRUE);
+#else
 	main_dialogs_open((gchar *)user_data, (gchar *)settings.currentverse);
+#endif
 }
 
 /******************************************************************************
@@ -813,8 +837,11 @@ void on_add_bookmark_activate(GtkMenuItem * menuitem, gpointer user_data)
 {	
 	gchar *label = g_strdup_printf("%s, %s",settings.currentverse,
 					settings.MainWindowModule);
-	gtk_dialog_run((GtkDialog *)gui_create_dialog_add_bookmark(label,
-			settings.MainWindowModule, settings.currentverse));
+	//gint result = gtk_dialog_run((GtkDialog *)
+	gui_bookmark_dialog(label,
+			settings.MainWindowModule, settings.currentverse);
+	
+	
 	g_free(label);	
 }
 
