@@ -25,17 +25,21 @@
 
 #include <gnome.h>
 #include <gtkhtml/gtkhtml.h>
+
+#ifdef USE_GTKHTML38
+#include "editor/html-editor.h"
+#else
 #include <gtkhtml/htmlengine.h>
-/*
-#ifdef USE_GTKHTML30
-#include <gal/widgets/e-unicode.h>
+#include "editor/editor-control.h"
 #endif
-*/
+
+
 #ifdef USE_GTKMOZEMBED
 #include <gtkmozembed.h>
 #endif
 
 #include "gui/commentary.h"
+#include "gui/bookmark_dialog.h"
 #include "gui/bookmarks_treeview.h"
 #include "gui/gnomesword.h"
 #include "gui/cipher_key_dialog.h"
@@ -46,6 +50,7 @@
 #include "gui/font_dialog.h"
 #include "gui/widgets.h"
 
+
 #include "main/embed.h"
 #include "main/settings.h"
 #include "main/lists.h"
@@ -180,9 +185,15 @@ static gboolean on_comm_button_release_event(GtkWidget * widget,
 	case 2:
 		if (!in_url)
 			break;
+#ifdef USE_GTKHTML38
+		url = gtk_html_get_url_at (GTK_HTML(widgets.html_text),		
+								event->x,
+								event->y);
+#else
 		url = html_engine_get_link_at (GTK_HTML(widgets.html_comm)->engine,
 					 event->x,
 					 event->y);
+#endif
 		if(strstr(url,"sword://")) {
 			gchar **work_buf = g_strsplit (url,"/",4);
 			gui_open_passage_in_new_tab(work_buf[3]);
@@ -482,8 +493,12 @@ void gui_lookup_comm_selection(GtkMenuItem * menuitem,
 
 static void edit_percomm(GtkMenuItem * menuitem, gpointer user_data)
 {
+#ifdef USE_GTKHTML38
+	editor_create_new((gchar *)user_data,(gchar *)settings.currentverse,TRUE);
+#else
 //	gui_open_commentary_editor((gchar *) user_data);
 	main_dialogs_open((gchar *)user_data, (gchar *)settings.currentverse);
+#endif
 }
 
 /******************************************************************************
@@ -525,8 +540,8 @@ static void on_add_bookmark_activate(GtkMenuItem * menuitem,
 	gchar *label = g_strdup_printf("%s, %s",settings.currentverse,
 					settings.CommWindowModule);
 
-	gtk_dialog_run((GtkDialog *)gui_create_dialog_add_bookmark(label,
-			settings.CommWindowModule, settings.currentverse));
+	gui_bookmark_dialog(label,
+			settings.CommWindowModule, settings.currentverse);
 	g_free(label);	
 	
 }
