@@ -30,6 +30,7 @@
 #endif
 
 #include "gui/dictlex.h"
+#include "gui/bookmark_dialog.h"
 #include "gui/bookmarks_treeview.h"
 #include "gui/gnomesword.h"
 #include "gui/cipher_key_dialog.h"
@@ -812,8 +813,7 @@ static void on_add_bookmark_activate(GtkMenuItem * menuitem,
 	gchar *label = g_strdup_printf("%s, %s",settings.dictkey,
 					settings.DictWindowModule);
 
-	gtk_dialog_run((GtkDialog *)gui_create_dialog_add_bookmark(label,
-			settings.DictWindowModule, settings.dictkey));
+	gui_bookmark_dialog(label,settings.DictWindowModule, settings.dictkey);
 	g_free(label);	
 	
 }
