@@ -27,13 +27,17 @@
 
 #include <gnome.h>
 #include <gtkhtml/gtkhtml.h>
+
+#ifndef USE_GTKHTML38
 #include <gtkhtml/htmlengine.h>
+#endif
 
 #ifdef USE_GTKMOZEMBED
 #include <gtkmozembed.h>
 #endif
 
 //#include "gui/gtkhtml_display.h"
+#include "gui/bookmark_dialog.h"
 #include "gui/bookmarks_treeview.h"
 #include "gui/gbs.h"
 #include "gui/gbs_dialog.h"
@@ -155,9 +159,15 @@ static gboolean on_book_button_release_event(GtkWidget * widget,
 	case 2:
 		if (!in_url)
 			break;
+#ifdef USE_GTKHTML38
+		url = gtk_html_get_url_at (GTK_HTML(widgets.html_text),		
+								event->x,
+								event->y);
+#else
 		url = html_engine_get_link_at (GTK_HTML(widgets.html_book)->engine,
 					 event->x,
 					 event->y);
+#endif
 		if(strstr(url,"sword://")) {
 			gchar **work_buf = g_strsplit (url,"/",4);
 			gui_open_passage_in_new_tab(work_buf[3]);
@@ -604,8 +614,7 @@ static void on_add_bookmark_activate(GtkMenuItem * menuitem,
 	gchar *local_name = main_get_treekey_local_name(settings.book_offset);
 	gchar *label = g_strdup_printf("%s, %s",local_name,settings.book_mod);
 
-	gtk_dialog_run((GtkDialog *)gui_create_dialog_add_bookmark(label,
-			settings.book_mod, key));
+	gui_bookmark_dialog(label, settings.book_mod, key);
 	g_free(label);	
 	g_free(local_name);		
 	g_free(key);	
