@@ -318,8 +318,7 @@ void gui_create_gbs_dialog(DIALOG_DATA * dlg)
 	gtk_window_set_title(GTK_WINDOW(dlg->dialog),
 			     main_get_module_description(dlg->mod_name));
 	gtk_window_set_default_size(GTK_WINDOW(dlg->dialog), 525, 306);
-	gtk_window_set_policy(GTK_WINDOW(dlg->dialog), TRUE, TRUE,
-			      FALSE);
+	gtk_window_set_resizable(GTK_WINDOW(dlg->dialog), TRUE);
 
 	vbox_dialog = gtk_vbox_new(FALSE, 0);
 	gtk_widget_show(vbox_dialog);
@@ -344,7 +343,9 @@ void gui_create_gbs_dialog(DIALOG_DATA * dlg)
 	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW
 				       (scrolledwindow_ctree),
 				       GTK_POLICY_AUTOMATIC,
-				       GTK_POLICY_AUTOMATIC);	
+				       GTK_POLICY_AUTOMATIC);
+	gtk_scrolled_window_set_shadow_type((GtkScrolledWindow *)scrolledwindow_ctree,
+                                             settings.shadow_type);	
 				    
 	model = create_model();			       
 	dlg->tree = gtk_tree_view_new_with_model(model);
@@ -365,6 +366,8 @@ void gui_create_gbs_dialog(DIALOG_DATA * dlg)
 				       (scrolledwindow_html),
 				       GTK_POLICY_AUTOMATIC,
 				       GTK_POLICY_AUTOMATIC);
+	gtk_scrolled_window_set_shadow_type((GtkScrolledWindow *)scrolledwindow_html,
+                                             settings.shadow_type);
 
 	dlg->html = gtk_html_new();
 	gtk_widget_show(dlg->html);
