@@ -24,11 +24,11 @@
 #endif
 
 #include <gnome.h>
+#include <libxml/tree.h>
 #include <libxml/parser.h>
 
 
 #include "gui/gnomesword.h"
-//#include "gui/gtkhtml_display.h"
 #include "gui/tabbed_browser.h"
 #include "gui/bibletext.h"
 #include "gui/bibletext_dialog.h"
@@ -45,20 +45,20 @@
 #include "gui/dictlex.h"
 #include "gui/widgets.h"
 
-//#include "main/bibletext.h"
-#include "main/settings.h"
-#include "main/lists.h"
-#include "main/sword.h"
-#include "main/xml.h"
 
-static void on_notebook_main_switch_page(GtkNotebook * notebook,
-					GtkNotebookPage * page,
-					gint page_num, GList **tl);
+#include "main/lists.h"
+#include "main/settings.h"
+#include "main/sword.h"
+#include "main/tab_history.h"
+#include "main/xml.h"
+	
 static GtkWidget* tab_widget_new(PASSAGE_TAB_INFO *tbinf,
 					const gchar *label_text);
+void notebook_main_add_page(PASSAGE_TAB_INFO *tbinf);
+void set_current_tab (PASSAGE_TAB_INFO *pt);
 
 
-
+GList *passage_list;
 
 /******************************************************************************
  * externs
@@ -70,54 +70,147 @@ PASSAGE_TAB_INFO *cur_passage_tab;
 /******************************************************************************
  * globals to this file only 
  */
-static GList *passage_list;
 static gboolean page_change = FALSE;
-//static gboolean display_change = TRUE;
 static gint removed_page;
+static const gchar *default_tab_filename = ".last_session_tabs";
+
+static int yes_no2true_false(const gchar * yes_no)
+{
+	if (yes_no && !strcmp(yes_no, "yes"))
+		return TRUE;
+	else
+		return FALSE;
+}
+
+static gchar *true_false2yes_no(int true_false)
+{
+	if (true_false)
+		return "yes";
+	else
+		return "no";
+}
 
 
 /******************************************************************************
  * Name
- *  
+ *  set_current_tab
  *
  * Synopsis
  *   #include "tabbed_browser.h"
  *
- *   	
+ *   void set_current_tab (PASSAGE_TAB_INFO *pt)	
  *
  * Description
- *   
+ *   point cur_passage_tab to the current tab and turns the close button on 
+ *   and off
+ *
+ * Return value
+ *   void
+ */
+ 
+void set_current_tab (PASSAGE_TAB_INFO *pt)
+{
+	PASSAGE_TAB_INFO *ot = cur_passage_tab;
+	
+	if (ot != NULL && ot->button_close != NULL) {
+		gtk_widget_hide (ot->button_close);
+		gtk_widget_show (ot->close_pixmap);
+	}
+	cur_passage_tab = pt;
+	if (pt != NULL && pt->button_close != NULL) {
+		main_update_tab_history_menu((PASSAGE_TAB_INFO*)pt);
+		gtk_widget_show (pt->button_close);
+		gtk_widget_hide (pt->close_pixmap);
+	}
+}
+
+
+/******************************************************************************
+ * Name
+ *  notebook_main_add_page
+ *
+ * Synopsis
+ *   #include "tabbed_browser.h"
+ *
+ *   void notebook_main_add_page(PASSAGE_TAB_INFO *tbinf)
+ *
+ * Description
+ *   adds a new page and label to the main notebook for a new scripture passage
+ *
+ * Return value
+ *   void
+ */
+void notebook_main_add_page(PASSAGE_TAB_INFO *tbinf)
+{
+	GtkWidget *tab_widget;
+	GtkWidget *menu_label;
+	GString *str = g_string_new(NULL);
+
+	
+	tbinf->page_widget = gtk_vbox_new (FALSE, 0);
+	gtk_widget_show(tbinf->page_widget);
+
+	g_string_printf(str,"%s: %s", tbinf->text_mod, tbinf->text_commentary_key); 
+	//tab_widget = tab_widget_new(tbinf, (gchar*)tbinf->text_commentary_key);
+	tab_widget = tab_widget_new(tbinf, str->str);
+	
+	gtk_notebook_append_page(GTK_NOTEBOOK(widgets.notebook_main),
+				 tbinf->page_widget, tab_widget);
+	
+//	gtk_notebook_set_menu_label_text(GTK_NOTEBOOK(widgets.notebook_main),
+//					tbinf->page_widget,
+//					(gchar*)tbinf->text_commentary_key);
+	gtk_notebook_set_menu_label_text(GTK_NOTEBOOK(widgets.notebook_main),
+					tbinf->page_widget, str->str);
+	
+	//menu_label = gtk_label_new((gchar*)tbinf->text_commentary_key);
+	menu_label = gtk_label_new(str->str);
+	gtk_notebook_set_menu_label(GTK_NOTEBOOK(widgets.notebook_main),
+                                             tbinf->page_widget,
+                                             menu_label);
+	g_string_free(str,TRUE);
+}
+
+
+/******************************************************************************
+ * Name
+ *   gui_save_tabs
+ *
+ * Synopsis
+ *   #include "tabbed_browser.h"
+ *
+ * Description
+ *   Saves the information for the current set of tabs.
  *
  * Return value
  *   
  */
-/* 
-static void save_tabs(void) //const gchar * filename)
+
+void gui_save_tabs(const gchar *filename)
 {
 	xmlDocPtr xml_doc;
 	xmlNodePtr root_node;
 	xmlNodePtr cur_node;
 	xmlNodePtr section_node;
 	xmlAttrPtr xml_attr;
-	const xmlChar *xml_filename;
+	//const xmlChar *xml_filename;
 	gchar *tabs_dir;
 	gchar *file;
 	GList *tmp = NULL;
 	PASSAGE_TAB_INFO *pt;
-	gchar * filename = "mytabs.xml";
-	
+	if (NULL == filename)
+		filename = default_tab_filename;
 	
 	tabs_dir = g_strdup_printf("%s/tabs/",settings.gSwordDir);
-
 	
 	if (access(tabs_dir, F_OK) == -1) {
 		if ((mkdir(tabs_dir, S_IRWXU)) == -1) {
 			printf("can't create tabs dir");
 			return;
 		}
-	}	
-	file = g_strdup_printf("%s/%s",tabs_dir,filename);
-	xml_filename = (const xmlChar *) file;
+	}
+	file = g_strdup_printf("%s%s",tabs_dir,filename);
+	//xml_filename = (const xmlChar *) file;
 	
 	xml_doc = xmlNewDoc((const xmlChar *) "1.0");
 
@@ -127,38 +220,184 @@ static void save_tabs(void) //const gchar * filename)
 		return;
 	}
 
-	root_node = xmlNewNode(NULL, (const xmlChar *) "GnomeSword");
-	xml_attr = xmlNewProp(root_node, "Version", VERSION);
+	root_node = xmlNewNode(NULL, (const xmlChar *) "GnomeSword_Tabs");
+	xml_attr = xmlNewProp(root_node, (const xmlChar *)"Version", (const xmlChar *) VERSION);
 	xmlDocSetRootElement(xml_doc, root_node);
 	
 	section_node = xmlNewChild(root_node, NULL,
 				   (const xmlChar *) "tabs", NULL);
-	tmp = passage_list;
-	tmp = g_list_first(tmp);
+	
+	tmp = g_list_first(passage_list);
 	while (tmp != NULL) {
 		pt = (PASSAGE_TAB_INFO*) tmp->data;
+		
 		cur_node = xmlNewChild(section_node,
 				NULL, (const xmlChar *) "tab", NULL);
-		xmlNewProp(cur_node,"text_mod",
+		xmlNewProp(cur_node,(const xmlChar *)"text_mod",
 				(const xmlChar *)pt->text_mod);		
-		xmlNewProp(cur_node, "commentary_mod", 
+		xmlNewProp(cur_node, (const xmlChar *)"commentary_mod", 
 				(const xmlChar *)pt->commentary_mod);
-		xmlNewProp(cur_node, "dictlex_mod",
+		xmlNewProp(cur_node, (const xmlChar *)"dictlex_mod",
 				(const xmlChar *)pt->dictlex_mod);		
-		xmlNewProp(cur_node, "book_mod", 
+		xmlNewProp(cur_node, (const xmlChar *)"book_mod", 
 				(const xmlChar *)pt->book_mod);
-		xmlNewProp(cur_node, "text_commentary_key",
+		xmlNewProp(cur_node, (const xmlChar *)"text_commentary_key",
 				(const xmlChar *)pt->text_commentary_key);		
-		xmlNewProp(cur_node, "dictlex_key", 
+		xmlNewProp(cur_node, (const xmlChar *)"dictlex_key", 
 				(const xmlChar *)pt->dictlex_key);		
-		xmlNewProp(cur_node, "book_key", 
-				(const xmlChar *)pt->book_key);
+		xmlNewProp(cur_node, (const xmlChar *)"book_offset", 
+				(const xmlChar *)pt->book_offset);		
+		xmlNewProp(cur_node, (const xmlChar *)"comm_showing", 
+				(const xmlChar *)true_false2yes_no(pt->comm_showing));
 		tmp = g_list_next(tmp);
 	}
-	xmlSaveFormatFile(xml_filename, xml_doc,1);
+	xmlSaveFormatFile(file, xml_doc,1);
 	xmlFreeDoc(xml_doc);
 }
-*/
+
+
+/******************************************************************************
+ * Name
+ *   gui_load_tabs
+ *
+ * Synopsis
+ *   #include "tabbed_browser.h"
+ *
+ * Description
+ *   Load the tabs from the given file.
+ *
+ * Return value
+ *   
+ */
+
+void gui_load_tabs(const gchar *filename)
+{
+	xmlDocPtr xml_doc;
+	xmlNodePtr tmp_node, childnode;
+	//const xmlChar *xml_filename;
+	gchar *tabs_dir, *file, *val;
+	gboolean error = FALSE;
+
+	GList *tmp = NULL;
+	PASSAGE_TAB_INFO *pt = NULL;
+
+	if (filename == NULL)
+	{
+		error = TRUE;
+	}
+	else
+	{
+		tabs_dir = g_strdup_printf("%s/tabs/",settings.gSwordDir);
+		if (access(tabs_dir, F_OK) == -1) {
+			printf("creating new Tabs directory\n");
+			gui_save_tabs(NULL);
+			//return;
+		}	
+		file = g_strdup_printf("%s%s",tabs_dir,filename);
+
+		//xml_filename = (const xmlChar *) file;
+		xml_doc = xmlParseFile(file);
+		if (xml_doc == NULL) {
+			fprintf(stderr, "Document not parsed successfully. \n");
+			error = TRUE;
+		}
+		else {
+			tmp_node = xmlDocGetRootElement(xml_doc);
+			if (tmp_node == NULL) {
+				fprintf(stderr,"empty document\n");
+				xmlFreeDoc(xml_doc);
+				error = TRUE;
+			}
+			else if (xmlStrcmp(tmp_node->name, (const xmlChar *)"GnomeSword_Tabs")) {
+				fprintf(stderr,"document of the wrong type, root node != GnomeSword_Tabs");
+				xmlFreeDoc(xml_doc);
+				error = TRUE;
+			}
+		}
+		
+		if (error == FALSE)
+		{
+			for (childnode = tmp_node->children; childnode != NULL; childnode = childnode->next)
+			{
+				if (!xmlStrcmp(childnode->name, (const xmlChar*)"tabs"))
+				{
+					tmp_node = childnode;
+					for (tmp_node = tmp_node->children; tmp_node != NULL; tmp_node = tmp_node->next)
+					{
+						if (!xmlStrcmp(tmp_node->name, (const xmlChar*)"tab"))
+						{
+							pt = g_new0(PASSAGE_TAB_INFO, 1);
+							
+							val = (gchar*)xmlGetProp(tmp_node, (const xmlChar *)"text_mod");
+							pt->text_mod = g_strdup(val);
+							xmlFree(val);
+							val = (gchar*)xmlGetProp(tmp_node, (const xmlChar *)"commentary_mod");
+							pt->commentary_mod = g_strdup(val);
+							xmlFree(val);
+							val = (gchar*)xmlGetProp(tmp_node, (const xmlChar *)"dictlex_mod");
+							pt->dictlex_mod = g_strdup(val);
+							xmlFree(val);
+							val = (gchar*)xmlGetProp(tmp_node, (const xmlChar *)"book_mod");
+							pt->book_mod = g_strdup(val);
+							xmlFree(val);
+							val = (gchar*)xmlGetProp(tmp_node, (const xmlChar *)"text_commentary_key");
+							pt->text_commentary_key = g_strdup(val);
+							xmlFree(val);
+							val = (gchar*)xmlGetProp(tmp_node, (const xmlChar *)"dictlex_key");
+							pt->dictlex_key = g_strdup(val);
+							xmlFree(val);
+							val = (gchar*)xmlGetProp(tmp_node, (const xmlChar *)"book_offset");
+							pt->book_offset = g_strdup(val);
+							xmlFree(val);					
+							val = (gchar*)xmlGetProp(tmp_node, (const xmlChar *)"comm_showing");
+							pt->comm_showing = yes_no2true_false(val);
+							xmlFree(val);
+							pt->history_items = 0;	
+							pt->current_history_item = 0;
+							pt->first_back_click = TRUE;
+							main_add_tab_history_item((PASSAGE_TAB_INFO*)pt);							
+							passage_list = g_list_append(passage_list, (PASSAGE_TAB_INFO*)pt);
+							notebook_main_add_page(pt);
+						}
+					}
+				}
+			}
+		}
+		xmlFreeDoc(xml_doc);
+	
+		if (error == TRUE || pt == NULL) {
+			pt = g_new0(PASSAGE_TAB_INFO, 1);
+			pt->text_mod = g_strdup(settings.MainWindowModule);
+			pt->commentary_mod = g_strdup(settings.CommWindowModule);
+			pt->dictlex_mod = g_strdup(settings.DictWindowModule);
+			pt->book_mod = g_strdup(settings.book_mod);//NULL;
+			pt->text_commentary_key = g_strdup(settings.currentverse);
+			pt->dictlex_key = g_strdup(settings.dictkey);
+			pt->book_offset = NULL; //settings.book_offset = atol(xml_get_value( "keys", "offset"));
+			pt->history_items = 0;	
+			pt->current_history_item = 0;
+			pt->first_back_click = TRUE;
+//			main_add_tab_history_item((PASSAGE_TAB_INFO*)pt);
+			passage_list = g_list_append(passage_list, (PASSAGE_TAB_INFO*)pt);
+			notebook_main_add_page(pt);
+		}
+		else
+		{
+			// This is a hack to keep gs from loading the settings from the last session
+			// into the last tab loaded here.
+			settings.MainWindowModule = g_strdup(pt->text_mod);
+			settings.CommWindowModule = g_strdup(pt->commentary_mod);
+			settings.DictWindowModule = g_strdup(pt->dictlex_mod);
+			settings.book_mod = g_strdup(pt->book_mod);
+			settings.currentverse = g_strdup(pt->text_commentary_key);
+			settings.dictkey = g_strdup(pt->dictlex_key);
+			settings.book_offset = atol(pt->book_offset);
+		}
+	}
+	gtk_notebook_set_current_page(GTK_NOTEBOOK(widgets.notebook_main),
+			gtk_notebook_page_num(GTK_NOTEBOOK(widgets.notebook_main), pt->page_widget));
+	set_current_tab(pt);
+}
 
 
 /******************************************************************************
@@ -186,39 +425,6 @@ static void on_notebook_main_close_page(GtkButton * button, gpointer user_data)
 }
 
 
-/******************************************************************************
- * Name
- *  set_current_tab
- *
- * Synopsis
- *   #include "tabbed_browser.h"
- *
- *   void set_current_tab (PASSAGE_TAB_INFO *pt)	
- *
- * Description
- *   point cur_passage_tab to the current tab and turns the close button on 
- *   and off
- *
- * Return value
- *   void
- */
- 
-static void set_current_tab (PASSAGE_TAB_INFO *pt)
-{
-	PASSAGE_TAB_INFO *ot = cur_passage_tab;
-	
-	if (ot != NULL && ot->button_close != NULL) {
-		gtk_widget_hide (ot->button_close);
-		gtk_widget_show (ot->close_pixmap);
-	}
-	cur_passage_tab = pt;
-	if (pt != NULL && pt->button_close != NULL) {
-		gtk_widget_show (pt->button_close);
-		gtk_widget_hide (pt->close_pixmap);
-	}
-}
-
-
 /******************************************************************************
  * Name
  *  tab_widget_new
@@ -289,12 +495,12 @@ static GtkWidget* tab_widget_new(PASSAGE_TAB_INFO *tbinf, const gchar *label_tex
 
 /******************************************************************************
  * Name
- *  on_notebook_main_switch_page
+ *  gui_notebook_main_switch_page
  *
  * Synopsis
  *   #include "tabbed_browser.h"
  *
- *   void on_notebook_main_switch_page(GtkNotebook * notebook,
+ *   void gui_notebook_main_switch_page(GtkNotebook * notebook,
  *				  GtkNotebookPage * page,
  *				  gint page_num, GList * tl)	
  *
@@ -304,13 +510,15 @@ static GtkWidget* tab_widget_new(PASSAGE_TAB_INFO *tbinf, const gchar *label_tex
  * Return value
  *   void
  */
-static void on_notebook_main_switch_page(GtkNotebook * notebook,
+void gui_notebook_main_switch_page(GtkNotebook * notebook,
 					 GtkNotebookPage * page,
 					 gint page_num, GList **tl)
 { 
 	gint number_of_pages = gtk_notebook_get_n_pages(notebook);
 	PASSAGE_TAB_INFO *pt;
-	
+#ifdef DEBUG
+	printf("\n on_notebook_main_switch_page \n");
+#endif	
 	page_change = TRUE;
 	/* get data structure for new passage */
 	/*
@@ -326,63 +534,28 @@ static void on_notebook_main_switch_page(GtkNotebook * notebook,
 	/* point PASSAGE_TAB_INFO *cur_passage_tab to pt - cur_passage_tab is global to this file */
 	set_current_tab (pt);
 	
+	//sets the book mod and key
+	main_display_book(pt->book_mod, pt->book_offset);
+	
 	//sets the commentary mod and key
-	if(pt->comm_showing)
-		main_display_commentary(pt->commentary_mod, 
-				pt->text_commentary_key);
-	else
-		main_display_book(pt->book_mod, pt->book_offset);
-	
-//	set_commentary_key(pt->commentary_mod, pt->text_commentary_key);
-	
+	main_display_commentary(pt->commentary_mod, pt->text_commentary_key);
+	 
 	//sets the text mod and key
 	main_display_bible(pt->text_mod, pt->text_commentary_key);
 	main_update_nav_controls(pt->text_commentary_key);
 	
 	//sets the dictionary mod and key
 	main_display_dictionary(pt->dictlex_mod, pt->dictlex_key);
-//	gui_set_dictlex_mod_and_key(pt->dictlex_mod, pt->dictlex_key);
+
+	if(pt->comm_showing)
+		gtk_notebook_set_current_page(GTK_NOTEBOOK(
+					widgets.notebook_comm_book),
+					0);
+	else
+		gtk_notebook_set_current_page(GTK_NOTEBOOK(
+					widgets.notebook_comm_book),
+					1);	
 	page_change = FALSE;
-	//gtk_notebook_reorder_child(notebook,GTK_WIDGET(pt->page_widget),0);
-	//sets the book mod and key
-}
-
-/******************************************************************************
- * Name
- *  notebook_main_add_page
- *
- * Synopsis
- *   #include "tabbed_browser.h"
- *
- *   void notebook_main_add_page(PASSAGE_TAB_INFO *tbinf)
- *
- * Description
- *   adds a new page and label to the main notebook for a new scripture passage
- *
- * Return value
- *   void
- */
-static void notebook_main_add_page(PASSAGE_TAB_INFO *tbinf)
-{
-	GtkWidget *tab_widget;
-	GtkWidget *menu_label;
-	
-	tbinf->page_widget = gtk_vbox_new (FALSE, 0);
-	gtk_widget_show(tbinf->page_widget);
-
-	tab_widget = tab_widget_new(tbinf, (gchar*)tbinf->text_commentary_key);
-
-	gtk_notebook_append_page(GTK_NOTEBOOK(widgets.notebook_main),
-				 tbinf->page_widget, tab_widget);
-	
-	gtk_notebook_set_menu_label_text(GTK_NOTEBOOK(widgets.notebook_main),
-					tbinf->page_widget,
-					(gchar*)tbinf->text_commentary_key);
-	
-	menu_label = gtk_label_new((gchar*)tbinf->text_commentary_key);	
-	gtk_notebook_set_menu_label(GTK_NOTEBOOK(widgets.notebook_main),
-                                             tbinf->page_widget,
-                                             menu_label);
 }
 
 
@@ -414,10 +587,14 @@ void gui_set_tab_label(const gchar * key)
 				cur_passage_tab->text_mod,
 				cur_passage_tab->text_commentary_key); 
 	gtk_label_set_text (cur_passage_tab->tab_label,str->str);
+#ifdef DEBUG 
+	g_print("label = %s\n",str->str);	
+#endif
 	gtk_notebook_set_menu_label_text(
 					GTK_NOTEBOOK(widgets.notebook_main),
                                         cur_passage_tab->page_widget,
                                             str->str );
+	main_add_tab_history_item((PASSAGE_TAB_INFO*)cur_passage_tab);
 	g_string_free(str,TRUE);
 }
 
@@ -475,7 +652,7 @@ void gui_update_tab_struct(const gchar * text_mod,
 	if(book_offset) {
 		if(cur_passage_tab->book_offset)
 			g_free(cur_passage_tab->book_offset);
-		cur_passage_tab->book_offset = g_strdup(book_mod);		
+		cur_passage_tab->book_offset = g_strdup(book_offset);		
 	}
 	/*if(text_commentary_key) {
 		if(cur_passage_tab->text_commentary_key)
@@ -517,10 +694,14 @@ void gui_open_passage_in_new_tab(gchar *verse_key)
 	pt->book_mod = g_strdup(settings.book_mod);
 	pt->text_commentary_key = g_strdup(verse_key);
 	pt->dictlex_key = g_strdup(settings.dictkey);
-	pt->book_offset = NULL;
+	pt->book_offset = g_strdup_printf("%d",settings.book_offset);
 	pt->comm_showing = settings.comm_showing;
+	pt->history_items = 0;	
+	pt->current_history_item = 0;
+	pt->first_back_click = TRUE;
+	main_add_tab_history_item((PASSAGE_TAB_INFO*)pt);
 	
-	passage_list = g_list_append(passage_list, (PASSAGE_TAB_INFO*)pt);
+	passage_list = g_list_append(passage_list, (PASSAGE_TAB_INFO*)pt);	
 	set_current_tab(pt);
 	notebook_main_add_page(pt);
 	
@@ -590,7 +771,7 @@ void gui_open_module_in_new_tab(gchar *module)
 		
 	pt->text_commentary_key = g_strdup(settings.currentverse);
 	pt->dictlex_key = g_strdup(settings.dictkey);	
-	pt->book_offset = NULL;
+	pt->book_offset = g_strdup_printf("%d",settings.book_offset);
 	pt->comm_showing = settings.comm_showing;
 	
 	passage_list = g_list_append(passage_list, (PASSAGE_TAB_INFO*)pt);
@@ -606,7 +787,7 @@ void gui_open_module_in_new_tab(gchar *module)
 
 /******************************************************************************
  * Name
- *  gui_close_al_tabs
+ *  gui_close_all_tabs
  *
  * Synopsis
  *   #include "tabbed_browser.h"
@@ -614,7 +795,7 @@ void gui_open_module_in_new_tab(gchar *module)
  *   void gui_close_all_tabs(void)
  *
  * Description
- *   called from preferences dialog when disable browsing is choosen
+ *   called from preferences dialog when disable browsing is chosen
  *
  * Return value
  *   void
@@ -647,6 +828,33 @@ void gui_close_all_tabs(void)
 }
 
 
+/******************************************************************************
+ * Name
+ *  gui_open_tabs
+ *
+ * Synopsis
+ *   #include "tabbed_browser.h"
+ *
+ *   void gui_open_tabs(void)
+ *
+ * Description
+ *   called from preferences dialog when enable browsing is chosen
+ *
+ * Return value
+ *   void
+ */
+void gui_open_tabs(void)
+{
+	removed_page = 1;
+	cur_passage_tab = NULL;
+	passage_list = NULL;
+
+	gui_load_tabs(default_tab_filename);
+
+	gtk_widget_show(widgets.button_new_tab);
+}
+
+
 /******************************************************************************
  * Name
  *  gui_close_passage_tab
@@ -703,66 +911,24 @@ static void on_notebook_main_new_tab_clicked(GtkButton *button, gpointer user_da
  * Return value
  *   void
  */
-void gui_notebook_main_setup(GList *ptlist)
+void gui_notebook_main_setup(void)
 {
-	GList *tmp = NULL;
-	PASSAGE_TAB_INFO *pt = NULL;
-	static gboolean connected = FALSE;
-	
 	removed_page = 1;
 	cur_passage_tab = NULL;
 	passage_list = NULL;
-	tmp = ptlist;
-	tmp = g_list_first(tmp);
-	while (tmp != NULL) {
-		pt = g_new0(PASSAGE_TAB_INFO, 1);
-		pt->text_mod = NULL;
-		pt->commentary_mod = NULL;
-		pt->dictlex_mod = NULL;
-		pt->book_mod = NULL;
-		pt->text_commentary_key = NULL;
-		pt->dictlex_key = NULL;
-		pt->book_offset = NULL;
 
-		passage_list = g_list_append(passage_list, (PASSAGE_TAB_INFO*)pt);
-		notebook_main_add_page(pt);
-		tmp = g_list_next(tmp);
-	}
-	if (NULL == pt) {
-		pt = g_new0(PASSAGE_TAB_INFO, 1);
-		pt->text_mod = g_strdup(settings.MainWindowModule);
-		pt->commentary_mod = g_strdup(settings.CommWindowModule);
-		pt->dictlex_mod = g_strdup(settings.DictWindowModule);
-		pt->book_mod = NULL;
-		pt->text_commentary_key = g_strdup(settings.currentverse);
-		pt->dictlex_key = g_strdup(settings.dictkey);
-		pt->book_offset = NULL;
-		passage_list = g_list_append(passage_list, (PASSAGE_TAB_INFO*)pt);
-		notebook_main_add_page(pt);
-	}
-	set_current_tab(pt);
-	/*
-	 * this is ugly :(
-	 * but when browsing is truned off and then back on in preferences
-	 * we don't need to connect or bad things happen since we are already
-	 * connected.
-	 *
-	 */
-	if(!connected) {
-		g_signal_connect(GTK_OBJECT(widgets.notebook_main),
-				   "switch_page",
-				   G_CALLBACK
-				   (on_notebook_main_switch_page), &passage_list);
-		g_signal_connect(GTK_OBJECT(widgets.button_new_tab), "clicked",
-				   G_CALLBACK(on_notebook_main_new_tab_clicked), NULL);
-		connected = TRUE;
-	}
+	gui_load_tabs(default_tab_filename);
+
+	g_signal_connect(GTK_OBJECT(widgets.notebook_main),
+			   "switch_page",
+			   G_CALLBACK
+			   (gui_notebook_main_switch_page), &passage_list);
+	g_signal_connect(GTK_OBJECT(widgets.button_new_tab), "clicked",
+			   G_CALLBACK(on_notebook_main_new_tab_clicked), NULL);
 		
 	//show the new tab button here instead of in main_window.c so it
 	//doesn't get shown if !settings.browsing
-	//gui_set_text_frame_label(cur_t);
 	gtk_widget_show(widgets.button_new_tab);
-	g_list_free(tmp);
 }
 
 /******************************************************************************
@@ -782,6 +948,7 @@ void gui_notebook_main_setup(GList *ptlist)
  */
 void gui_notebook_main_shutdown(void)
 {	
+	gui_save_tabs(default_tab_filename);
 	passage_list = g_list_first(passage_list);
 	while (passage_list != NULL) {
 		PASSAGE_TAB_INFO *pt = (PASSAGE_TAB_INFO*)passage_list->data;
