@@ -38,6 +38,225 @@
 #include "main/settings.h"
 #include "main/configs.h"
 #include "main/sword.h"
+ 
+
+
+void gui_set_progressbar_text(GtkWidget * pb, gchar * text)
+{
+	gtk_progress_bar_set_text(GTK_PROGRESS_BAR(pb), text);
+	while (gtk_events_pending()) {
+		gtk_main_iteration();
+	}  
+}
+
+
+void gui_set_progressbar_fraction(GtkWidget * pb, gdouble fraction)
+{
+	gtk_progress_bar_set_fraction(GTK_PROGRESS_BAR(pb), fraction);
+	while (gtk_events_pending()) {
+		gtk_main_iteration();
+	}  
+}
+
+
+void gui_set_combo_index(GtkWidget * combo, gint index)
+{
+	gtk_combo_box_set_active(GTK_COMBO_BOX(combo), index);
+}
+
+
+void gui_clear_combo(GtkWidget * combo)
+{
+	GtkTreeModel* model = gtk_combo_box_get_model(GTK_COMBO_BOX(combo));	
+	gtk_list_store_clear(GTK_LIST_STORE(model));
+}
+
+void gui_add_item_to_combo(GtkWidget * combo, gchar * item)
+{
+	GtkTreeIter iter;	
+	GtkTreeModel* model = gtk_combo_box_get_model(GTK_COMBO_BOX(combo));
+	gtk_list_store_append(GTK_LIST_STORE(model), &iter);
+	gtk_list_store_set(GTK_LIST_STORE(model), &iter, 0, (gchar*)item, -1);
+}
+
+
+/*
+ * taken from galeon 
+ * glade_signal_connect_func: used by glade_xml_signal_autoconnect_full
+ */
+void gui_glade_signal_connect_func (const gchar *cb_name, GObject *obj, 
+			   const gchar *signal_name, const gchar *signal_data,
+			   GObject *conn_obj, gboolean conn_after,
+			   gpointer user_data)
+{
+	/** Module with all the symbols of the program */
+	static GModule *mod_self = NULL;
+	gpointer handler_func;
+
+ 	/* initialize gmodule */
+	if (mod_self == NULL)
+	{
+		mod_self = g_module_open (NULL, 0);
+		g_assert (mod_self != NULL);
+	}
+
+	/*g_print( "glade_signal_connect_func: cb_name = '%s', signal_name = '%s', signal_data = '%s'\n",
+	  cb_name, signal_name, signal_data ); */
+	
+	if (g_module_symbol (mod_self, cb_name, &handler_func))
+	{
+		/* found callback */
+		if (conn_obj)
+		{
+			if (conn_after)
+			{
+				g_signal_connect_object
+                                        (obj, signal_name, 
+                                         handler_func, conn_obj,
+                                         G_CONNECT_AFTER);
+			}
+			else
+			{
+				g_signal_connect_object
+                                        (obj, signal_name, 
+                                         handler_func, conn_obj,
+                                         G_CONNECT_SWAPPED);
+			}
+		}
+		else
+		{
+			/* no conn_obj; use standard connect */
+			gpointer data = NULL;
+			
+			data = user_data;
+			
+			if (conn_after)
+			{
+				g_signal_connect_after
+					(obj, signal_name, 
+					 handler_func, data);
+			}
+			else
+			{
+				g_signal_connect
+					(obj, signal_name, 
+					 handler_func, data);
+			}
+		}
+	}
+	else
+	{
+		g_warning("callback function not found: %s", cb_name);
+	}
+}
+
+
+/**
+ * taken form galeon-1.3.21
+ * misc_general_user_file: returns the pathname of galeon shared files
+ * (e.g., galeon.glade)
+ *
+ * fname: just the filename with no path information
+ * critical: critical file? (halt if not found)
+ */
+gchar * gui_general_user_file (const char *fname, gboolean critical)
+{
+	static GHashTable *already_found = NULL;
+	gchar *alternative[6];
+	gchar *file;
+	gint i;
+	
+	/* create cache hash table if it doesnt already exist */
+	if (already_found == NULL)
+	{
+		already_found = g_hash_table_new_full (g_str_hash, g_str_equal,
+						       g_free, g_free);
+	}
+
+        /* Have we already found this? */
+	file = g_hash_table_lookup (already_found, fname);
+	if (file != NULL)
+	{
+		if (g_file_test (file, G_FILE_TEST_EXISTS))
+		{
+			return g_strdup (file);
+		}
+		else
+		{
+			g_hash_table_remove (already_found, fname);
+		}
+	}
+
+	/* try the default */
+	file = g_build_filename (g_get_home_dir (), ".gnomesword-2.0", fname, NULL);
+	
+	/* success? */
+	if (g_file_test (file, G_FILE_TEST_EXISTS))
+	{
+		/* add it to the set of found files */
+		g_hash_table_insert (already_found, g_strdup (fname), 
+				     g_strdup (file));
+		return file;
+	}
+	g_free(file);
+
+	/* specify alternate locations in order of precedence */
+	i = 0;
+	alternative[i++] = g_strdup (fname);
+#ifdef MAINTAINER_MODE
+	/* generally only developers have any use for these */
+	alternative[i++] = g_build_filename ("..", fname, NULL);
+	alternative[i++] = g_build_filename ("ui", fname, NULL);
+	alternative[i++] = g_build_filename ("..", "ui", fname, NULL);
+#endif
+	alternative[i++] = g_build_filename (SHARE_DIR, fname, NULL);
+	alternative[i++] = NULL;  /* NULL terminator needed */
+	
+	/* select one of the alternatives */
+	file = NULL;
+	for (i = 0; alternative[i] != NULL; i++)
+	{
+		if (file == NULL && g_file_test (alternative[i], G_FILE_TEST_EXISTS)) 
+		{
+			file = alternative[i];
+		}
+		else
+		{
+			/* free unused string */
+			g_free (alternative[i]);
+		}
+	}
+
+	/* check for success */
+	if (file != NULL)
+	{
+		/* warn if we're using other than the install default */
+		if (!g_path_is_absolute (file))
+		{
+			gchar * cwd, *file1;
+			g_message ("Using %s (usually OK)", file);
+
+			/* Make it absolute */
+			cwd = g_get_current_dir();
+			file1 = g_build_filename (cwd, file, NULL);
+			g_free (file);
+			g_free (cwd);
+			file = file1;
+		}
+
+		/* add it to the set of found files */
+		g_hash_table_insert (already_found, g_strdup (fname), 
+				     g_strdup (file));
+	}
+	/* if nothing then theres an error */
+	else if (critical)
+	{
+		g_error(_("%s not found"), fname);
+	}
+
+	/* return result */
+	return file;
+}
 
 
 /******************************************************************************
@@ -293,6 +512,7 @@ void gui_load_module_tree(GtkWidget * tree, gboolean is_sidebar)
 				GTK_TREE_MODEL(store));
 }
 
+
 /******************************************************************************
  * Name
  *  get_font
