@@ -22,16 +22,14 @@
 #ifndef ___BIBLETEXT_H_
 #define ___BIBLETEXT_H_
 
+
 #include <gnome.h>
 
 void gui_setup_bibletext(void);
-void gui_update_text_global_ops(gchar * option, gboolean choice);
-//void gui_display_text(const gchar * val_key);
 gboolean gui_text_button_release_event(GtkWidget * widget,
 					GdkEventButton * event,
 					gpointer data);
-void gui_popup_pm_text(gchar * mod_name, GdkEventButton * event);
+void gui_popup_pm_text(void);  //gchar * mod_name, GdkEventButton * event);
 GtkWidget *gui_create_bible_pane(void);
 
-
 #endif
