@@ -22,17 +22,21 @@
 #ifndef __BIBLETEXT_DIALOG_H__
 #define __BIBLETEXT_DIALOG_H__
 
-#include "gui/bibletext.h"
 
-void gui_keep_bibletext_dialog_in_sync(gchar * key);
-void gui_bibletext_dialog_goto_bookmark(gchar * mod_name, gchar * key);
-void gui_sync_bibletext_dialog_with_main(TEXT_DATA * vt);
+#ifdef __cplusplus
+extern "C" {
+#endif
+	
+#include "main/module_dialogs.h"
+
+
+void gui_create_bibletext_dialog(DIALOG_DATA * vt);
 void gui_on_lookup_bibletext_dialog_selection
 	(GtkMenuItem * menuitem, gchar * dict_mod_description);
-void gui_close_text_dialog(TEXT_DATA * vt);
-void gui_open_bibletext_dialog(gchar * mod_name);
-void gui_setup_bibletext_dialog(GList *mods);
-void gui_shutdown_bibletext_dialog(void);
+
+#ifdef __cplusplus
+}
+#endif
 
 #endif
 
