@@ -26,18 +26,17 @@
 extern "C" {
 #endif
 
-#include "gui/commentary.h"
+
+#include "main/module_dialogs.h"
+	
 	
 void gui_keep_comm_dialog_in_sync(gchar * key);	
 void gui_commentary_dialog_goto_bookmark(gchar * mod_name, gchar * key);
 void gui_on_lookup_commentary_dialog_selection
 	(GtkMenuItem * menuitem, gchar * dict_mod_description);
-void gui_close_comm_dialog(COMM_DATA * vc);
-void gui_open_commentary_dialog(gchar * mod_name);
-void gui_open_commentary_editor(gchar * mod_name);
-void gui_setup_commentary_dialog(GList *mods);
-void gui_shutdown_commentary_dialog(void);
+void gui_close_comm_dialog(DIALOG_DATA * vc);
 void gui_display_commentary_in_dialog(gchar * key);
+void gui_create_commentary_dialog(DIALOG_DATA * vc, gboolean do_edit);
 
 #ifdef __cplusplus
 }
