@@ -57,6 +57,8 @@ struct _gs_dialog {
 	gchar *label6;
 	gchar *label_bottom;
 	
+	gboolean no_save;
+	gboolean save;
 	gboolean ok;
 	gboolean cancel;
 	gboolean yes;
