@@ -33,19 +33,22 @@ extern "C" {
 }
 #endif
 
+/*
+#ifdef USE_GTKHTML30
 #include <gal/widgets/e-unicode.h>
-
+#endif
+*/
 #include "gui/parallel_view.h"
 #include "gui/parallel_dialog.h"
 #include "gui/html.h"
 #include "gui/widgets.h"
 
 #include "main/parallel_view.h"
-#include "main/bibletext.h"
 #include "main/global_ops.hh"
 #include "main/lists.h"
 #include "main/sword.h"
 #include "main/settings.h"
+#include "main/url.hh"
 #include "main/xml.h"
 
 
@@ -163,25 +166,7 @@ gchar *main_parallel_change_verse(void)
 
 gchar *main_parallel_update_controls(const gchar * ref)
 {
-	const gchar *bookname;
-	gchar buf[256];
-	gint chapter, verse;
-	char *newbook;
-
-	newbook = backend_p->key_get_book(ref); 
-	chapter = backend_p->key_get_chapter(ref);
-	verse = backend_p->key_get_verse(ref);
-
-	bookname = gtk_entry_get_text(GTK_ENTRY(entrycbIntBook));
-	if (strcmp(bookname, newbook))
-		gtk_entry_set_text(GTK_ENTRY(entrycbIntBook), newbook);
-	gtk_spin_button_set_value(GTK_SPIN_BUTTON(sbIntChapter),
-				  chapter);
-	gtk_spin_button_set_value(GTK_SPIN_BUTTON(sbIntVerse), verse);
-	sprintf(buf, "%s %d:%d", newbook, chapter, verse);
-	gtk_entry_set_text(GTK_ENTRY(entryIntLookup), buf);
-	g_free(newbook);
-	return g_strdup(buf);
+	return backend->get_valid_key(ref);
 }
 
 
@@ -535,7 +520,10 @@ void main_update_parallel_page(void)
 	gboolean was_editable, use_gtkhtml_font;
 	gboolean is_rtol = FALSE;
 	gchar *buf;
+	gchar *file = NULL;
 
+	settings.cvparallel = settings.currentverse;
+	
 	if (settings.havebible) {
 		/* setup gtkhtml widget */
 		GtkHTML *html = GTK_HTML(widgets.html_parallel);
@@ -603,7 +591,12 @@ void main_update_parallel_page(void)
 
 			++j;
 			is_rtol = main_is_mod_rtol(mod_name);
-			font_name = get_module_font_name(mod_name);
+			//font_name = get_module_font_name(mod_name);
+			file = g_strdup_printf("%s/fonts.conf", settings.gSwordDir);
+			font_name = get_conf_file_item(file, mod_name, "Font");
+			//g_free(file);
+			if (!font_name)
+				font_name = g_strdup("none");
 			if (strlen(font_name) < 2) {
 				use_gtkhtml_font = TRUE;
 //                                      g_warning("use_gtkhtml_font = TRUE");
@@ -616,8 +609,12 @@ void main_update_parallel_page(void)
 //                                      g_warning("use_gtkhtml_font = FALSE");
 				}
 			}
-
-			font_size = get_module_font_size(mod_name);
+			
+			//file = g_strdup_printf("%s/fonts.conf", settings.gSwordDir);			
+			font_size = get_conf_file_item(file, mod_name, "Fontsize");
+			g_free(file);//get_module_font_size(mod_name);			
+			if(!font_size)
+				font_size = g_strdup("+0");
 			if (strlen(font_size) < 2){
 				free(font_size);
 				font_size = g_strdup("+0");
@@ -645,10 +642,10 @@ void main_update_parallel_page(void)
 			}
 
 			sprintf(tmpBuf,
-				"<tr bgcolor=\"%s\"><td><b><a href=\"about://%s/%s\"><font color=\"%s\" size=\"%s\"> [%s]</font></a></b>",
+				"<tr bgcolor=\"%s\"><td><b><a href=\"gnomesword.url?action=showModInfo&value=%s&module=%s\"><font color=\"%s\" size=\"%s\"> [%s]</font></a></b>",
 				rowcolor,
-				mod_name,
 				main_get_module_description(mod_name),
+				mod_name,
 				settings.bible_verse_num_color,
 				settings.verse_num_font_size, mod_name);
 
@@ -708,7 +705,8 @@ void main_update_parallel_page(void)
 				}
 			}	
 			sprintf(tmpBuf,
-				"</font><small>[<a href=\"parallel://swap/%s\">view context</a>]</small></td></tr>",
+				"</font><small>[<a href=\"gnomesword.url?action=showParallel&"
+				"type=swap&value=%s\">view context</a>]</small></td></tr>",
 				mod_name);
 
 			utf8len = strlen(tmpBuf);
@@ -757,15 +755,19 @@ void main_update_parallel_page(void)
 
 static void int_display(gchar * key)
 {
-	gchar
-	    * utf8str,
-	    *bgColor,
-	    *textColor,
-	    buf[500], *tmpkey, tmpbuf[256], *mod_name, *use_font_size;
+	gchar  	* utf8str,
+	   	*bgColor,
+		*textColor,
+	    	buf[500], 
+		*tmpkey, 
+		tmpbuf[256], 
+		*mod_name, 
+		*use_font_size;
 	GString *str;
 	gboolean evenRow = FALSE;
 	gboolean is_rtol = FALSE;
 	gchar *buf2;
+	gchar *file = NULL;
 	gint utf8len, cur_verse, cur_chapter, i = 1, j;
 	char *cur_book;
 	GtkHTML *html = GTK_HTML(widgets.html_parallel);
@@ -838,7 +840,13 @@ static void int_display(gchar * key)
 
 			is_rtol = main_is_mod_rtol(mod_name);
 			
-			use_font_size = get_module_font_size(mod_name);
+			file = g_strdup_printf("%s/fonts.conf", settings.gSwordDir);			
+			use_font_size = get_conf_file_item(file, mod_name, "Fontsize");
+			g_free(file);
+			if(!use_font_size)
+				use_font_size = g_strdup("+0");			
+			
+			//use_font_size = get_module_font_size(mod_name);
 			if (strlen(use_font_size) < 2) {
 				free(use_font_size);
 				use_font_size = g_strdup("+0");
@@ -846,14 +854,17 @@ static void int_display(gchar * key)
 
 			g_string_printf(str,
 				"<td width=\"20%%\" bgcolor=\"%s\">"
-				"<a href=\"parallel://verse/%s\" name=\"%d\">"
+				"<a href=\"gnomesword.url?action=showParallel&"
+				"type=verse&value=%s\" name=\"%d\">"
 				"<font color=\"%s\">%d. </font></a>"
 				"<font size=\"%s\" color=\"%s\">",
 				bgColor,
-				tmpkey,
+				main_url_encode(tmpkey),
 				i,
 				settings.bible_verse_num_color,
-				i, use_font_size, textColor);
+				i, 
+				use_font_size, 
+				textColor);
 			if (str->len) {
 				gtk_html_write(GTK_HTML(html),
 					       htmlstream, str->str,
