@@ -28,6 +28,7 @@ extern "C" {
 
 #include <glib-2.0/glib.h>
 
+void main_comboboxentry2_changed(GtkComboBox * combobox, gpointer user_data);
 void main_dialog_search_percent_update(char percent, void *userData);
 void main_range_text_changed(GtkEditable * editable);	
 void main_save_modlist(void);
@@ -40,7 +41,7 @@ void main_selection_modules_lists_changed(GtkTreeSelection *
 				    selection, gpointer data);
 void main_mod_selection_changed(GtkTreeSelection * selection,
 				     GtkWidget * tree_widget);
-void main_do_dialog_search(gpointer user_data);
+void main_do_dialog_search(void);
 void main_open_search_dialog(void);
 void main_close_search_dialog(void);
 char *main_get_search_rendered_text(char *module_name, char *key);
