@@ -24,11 +24,7 @@
 #include <config.h>
 #endif
 
-#ifdef USE_GNOME2
 #include <glib-2.0/glib.h>
-#else
-#include <glib-1.2/glib.h>
-#endif
 
 #include <fcntl.h>
 #include <stdio.h>
@@ -41,10 +37,11 @@
 #include "gui/bookmarks.h"
 #include "gui/setup_druid.h"
 
+#include "main/lists.h"
 #include "main/settings.h"
 #include "main/xml.h"
 
-#include "backend/sword.h"
+//#include "backend/sword.h"
 
 
 /******************************************************************************
@@ -89,7 +86,9 @@ int settings_init(int new_configs, int new_bookmarks)
 	int need_old = FALSE;
 	char *sword_dir = NULL;
 	char *gs_old = NULL;
+	char *tabs = NULL;
 
+	settings.first_run = FALSE;
 	/* set program title */
 	strcpy(settings.program_title, "GnomeSword");
 
@@ -119,6 +118,13 @@ int settings_init(int new_configs, int new_bookmarks)
 		} 
 		g_free(gs_old);
 	}
+
+	/* check for tabs dir -- if directory does not exist create it */
+/*	tabs = g_strdup_printf("%s/tabs",settings.gSwordDir);
+	if (access(tabs, F_OK) == -1)
+		gui_save_tabs(NULL);
+	g_free(tabs);
+*/
 	
 	
 	/* if .sword does not exist create it */
@@ -155,13 +161,16 @@ int settings_init(int new_configs, int new_bookmarks)
 	sprintf(settings.fnconfigure, "%s/%s", settings.gSwordDir,
 		"settings.xml");
 	
-	/* if gSwordDir does not exist create it */
+	/* if settings.xml does not exist create it */
 	if (access(settings.fnconfigure, F_OK) == -1) {
 		/* must be first run */
+#ifdef DEBUG 
 		g_print("\nFirst Run: need to create settings!\n");
-		xml_create_settings_file(settings.fnconfigure);
+#endif
+		settings.first_run = TRUE;
 		main_init_lists();
-		retval = gui_first_run();
+		xml_create_settings_file(settings.fnconfigure);
+		//retval = gui_first_run();
 		main_shutdown_list();
 		xml_save_settings_doc(settings.fnconfigure);
 		xml_free_settings_doc();
@@ -170,6 +179,7 @@ int settings_init(int new_configs, int new_bookmarks)
 	xml_parse_settings_file(settings.fnconfigure);
 	load_settings_structure();
 	
+	
 	return retval;
 }
 
@@ -299,17 +309,12 @@ void load_settings_structure(void)
 	
 	settings.lex_greek = xml_get_value("lexicons", "greek");
 	settings.lex_hebrew = xml_get_value("lexicons", "hebrew");
-	settings.lex_greek_viewer =
-	    xml_get_value("lexicons", "greekviewer");
-	settings.lex_hebrew_viewer =
-	    xml_get_value("lexicons", "hebrewviewer");
-	settings.DefaultDict =
-	    xml_get_value("lexicons", "defaultdictionary");
-	settings.inViewer = atoi(xml_get_value("lexicons", "inviewer"));
-	settings.inDictpane =
-	    atoi(xml_get_value("lexicons", "indictpane"));
-	settings.useDefaultDict =
-	    atoi(xml_get_value("lexicons", "usedefaultdict"));
+	settings.lex_greek_viewer = xml_get_value("lexicons", "greekviewer");
+	settings.lex_hebrew_viewer = xml_get_value("lexicons", "hebrewviewer");
+	settings.DefaultDict = xml_get_value("lexicons", "defaultdictionary");
+//	settings.inViewer = atoi(xml_get_value("lexicons", "inviewer"));
+//	settings.inDictpane = atoi(xml_get_value("lexicons", "indictpane"));
+	settings.useDefaultDict = atoi(xml_get_value("lexicons","usedefaultdict"));
 
 
 	settings.currentverse = xml_get_value("keys", "verse");
@@ -328,7 +333,7 @@ void load_settings_structure(void)
 		settings.book_offset = 0;
 	}
 
-	settings.shortcutbar_width =
+	settings.sidebar_width =
 		atoi(xml_get_value("layout", "shortcutbar"));
 	if(xml_get_value("layout", "vltoppaneheight"))
 		settings.verselist_toppane_height =
@@ -337,6 +342,13 @@ void load_settings_structure(void)
 		xml_add_new_item_to_section("layout", "vltoppaneheight", "210");
 		settings.verselist_toppane_height = 210;
 	}
+	if(xml_get_value("layout", "sidebar_notebook_hight"))
+		settings.sidebar_notebook_hight =
+			atoi(xml_get_value("layout", "sidebar_notebook_hight"));
+	else {
+		xml_add_new_item_to_section("layout", "sidebar_notebook_hight", "300");
+		settings.sidebar_notebook_hight = 250;
+	}
 	settings.gs_hight = atoi(xml_get_value("layout", "hight"));
 	settings.gs_width = atoi(xml_get_value("layout", "width"));
 	
@@ -358,7 +370,20 @@ void load_settings_structure(void)
 	settings.upperpane_hight =
 	    atoi(xml_get_value("layout", "uperpane"));
 
+	if(xml_get_value("layout", "biblehight"))
+		settings.biblepane_hight = atoi(xml_get_value("layout", "biblehight"));
+	else {
+		xml_add_new_item_to_section("layout", "biblehight", "340");
+		settings.biblepane_hight = 250;
+	}
 
+	if(xml_get_value("layout", "commentaryhight"))
+		settings.commpane_hight = atoi(xml_get_value("layout", "commentaryhight"));
+	else {
+		xml_add_new_item_to_section("layout", "commentaryhight", "240");
+		settings.commpane_hight = 240;
+	}
+	
 	settings.verse_num_font_size =
 	    xml_get_value("fontsize", "versenum");
 
@@ -402,7 +427,13 @@ void load_settings_structure(void)
 	settings.showtexts = atoi(xml_get_value("misc", "showtexts"));
 	settings.showcomms = atoi(xml_get_value("misc", "showcomms"));
 	settings.showdicts = atoi(xml_get_value("misc", "showdicts"));
+
+//#ifdef USE_GTKHTML30	
 	settings.showsplash = atoi(xml_get_value("misc", "splash"));
+//#else	
+	//settings.showsplash = FALSE;	
+//#endif
+	
 	settings.showdevotional =
 	    atoi(xml_get_value("misc", "dailydevotional"));
 	settings.versestyle = atoi(xml_get_value("misc", "versestyle"));
@@ -416,12 +447,12 @@ void load_settings_structure(void)
 		settings.setup_canceled = atoi(xml_get_value("misc", "setup_canceled"));
 	}
 
-	settings.use_studypad =
+/*	settings.use_studypad =
 	    atoi(xml_get_value("editor", "UseStudyPad"));
 	settings.use_studypad_dialog =
 	    atoi(xml_get_value("editor", "UseStudypadDialog"));
 	settings.use_percomm_dialog =
-	    atoi(xml_get_value("editor", "UsePercommDialog"));
+	    atoi(xml_get_value("editor", "UsePercommDialog"));*/
 	if(xml_get_value("editor", "spell_language"))
 	     settings.spell_language = xml_get_value("editor","spell_language");
 	else {
@@ -433,48 +464,11 @@ void load_settings_structure(void)
 	settings.studypadfilename =
 	    xml_get_value("studypad", "lastfile");
 	settings.studypaddir = xml_get_value("studypad", "directory");
-	
-	buf = xml_get_value("studypad", "stylebar");
-	if(buf)
-		settings.show_style_bar_sp =  atoi(buf);
-	
-	buf = xml_get_value("studypad", "editbar");
-	if(buf)
-		settings.show_edit_bar_sp =  atoi(buf);
-
 
 	buf = xml_get_value("shortcutbar", "shortcutbar");
 	if(buf)
 		settings.showshortcutbar = atoi(buf);
 	
-	buf = xml_get_value("shortcutbar", "favo");
-	if(buf)
-		settings.showfavoritesgroup = atoi(buf);
-	
-	buf = xml_get_value("shortcutbar", "bible");
-	if(buf)
-		settings.showtextgroup = atoi(buf);
-	
-	buf = xml_get_value("shortcutbar", "comm");
-	if(buf)
-		settings.showcomgroup = atoi(buf);
-	
-	buf = xml_get_value("shortcutbar", "dict");
-	if(buf)
-		settings.showdictgroup = atoi(buf);
-	
-	buf = xml_get_value("shortcutbar", "book");
-	if(buf)
-		settings.showbookgroup = atoi(buf);
-	
-	buf = xml_get_value("shortcutbar", "bookmark");
-	if(buf)
-		settings.showbookmarksgroup = atoi(buf);
-	
-	buf = xml_get_value("shortcutbar", "history");
-	if(buf)
-		settings.showhistorygroup = atoi(buf);
-	
 	buf = xml_get_value("shortcutbar", "docked");
 	if(buf)
 		settings.docked =  atoi(buf);
@@ -488,25 +482,6 @@ void load_settings_structure(void)
 		settings.browsing = 1;
 	}
 	
-	buf = xml_get_value("tabs", "bible");
-	if(buf)
-		settings.text_tabs =  atoi(buf);
-	
-	buf = xml_get_value("tabs", "comm");
-	if(buf)
-		settings.comm_tabs =  atoi(buf);
-	
-	buf = xml_get_value("tabs", "dict");
-	if(buf)
-		settings.dict_tabs =  atoi(buf);
-	
-	buf = xml_get_value("tabs", "book");
-	if(buf)
-		settings.book_tabs =  atoi(buf);
-	
-	buf = xml_get_value("tabs", "percomm");
-	if(buf)
-		settings.percomm_tabs =  atoi(buf);
 	
 
 	/*
