@@ -22,6 +22,9 @@
 #ifndef _SETTINGS_H_
 #define _SETTINGS_H_
 
+//#include <gnome.h>
+
+#include <glib-2.0/glib.h>
 #ifdef __cplusplus
 extern "C" {
 #endif
@@ -65,13 +68,17 @@ struct _settings {
 	        *link_color,  /* color for strongs, morph tags */	
 		*bible_verse_num_color, /* verse number color */
 		*found_color, /* color to use for search word in results display */
+		*font_color, /*  */
 		*verse_num_font_size;		
 		
 	int 
-      		shortcutbar_width,
+      		sidebar_width,
 		verselist_toppane_height, //height of the top pane in the search results window
 		upperpane_hight,
 		biblepane_width,
+		biblepane_hight,
+		commpane_hight,
+		sidebar_notebook_hight,
 		gs_width,
 		tmp_width,
 		gs_hight,	
@@ -109,28 +116,22 @@ struct _settings {
 	        showhistorygroup, /* display shortcut bar group if true */
 		showsplash, /* show splash on program start if true */
 		showdevotional, /* show devotional on program start if true */
-		text_tabs, /* show module tabs in text window if true  */
 		text_tool, /* show toolbar in text window if true  */
-		comm_tabs, /* show module tabs in commentary window if true  */
-		comm_tool, /* show toolbar in commentary window if true  */
-		dict_tabs, /* show module tabs in text dict/lex if true  */
-		book_tabs, /* show module tabs in books if true  */
                 showtexts, /* show bible texts if true  */
                 showcomms, /* show commentaries if true  */
                 showdicts, /* show dictionaries/lexicons if true */
-		percomm_tabs, /* show module tabs in personal commentary if true  */
 		displaySearchResults, /* are we displaying search results in chap display */
 		showinmain, /* when verse list item clicked show in main form if true */
 		havethayer, /* for greek morph tags */
 		havebdb, /* for hebrew morph tags */
-		inViewer, /* display dict/lex in viewer when word or link clicked */
-		inDictpane, /* display dict/lex in Dict/Lex pane when word or link clicked */
+//		inViewer, /* display dict/lex in viewer when word or link clicked */
+//		inDictpane, /* display dict/lex in Dict/Lex pane when word or link clicked */
 		useDefaultDict,
-		strip_words_in_red,
+//		strip_words_in_red,
 		browsing, /* true for tabbed browsing */
 		
 		/** if items are docked **/
-		docked, /* true when shortcut bar is docked */
+		docked, /* true when sidebar is docked */
 		dockedInt, /* true when parallel page is docked */
 		
 		/**  find dialogs info  **/
@@ -142,13 +143,10 @@ struct _settings {
 		modifiedGBS, /* book entry modified */
 		modifiedPC, /* personal note modified */
 		modifiedSP, /* studypad file modified */
-		show_style_bar_sp, /* show style toolbar for studypad */
-		show_edit_bar_sp, /* show edit toolbar for studypad */
-		use_studypad, /* use studypad */
-		use_studypad_dialog, /* display studypad in a dialog */
+//		use_studypad, /* use studypad */
+//		use_studypad_dialog, /* display studypad in a dialog */
 		studypad_dialog_exist, /* studypad dialog has been created */
-		use_percomm_dialog, /* display personal 
-					comments editor in a dialog */
+//		use_percomm_dialog, /* display personal comments editor in a dialog */
 		percomm_dialog_exist, /* percomm dialog has been created */
 		
 		/** do we have these modules **/
@@ -210,6 +208,16 @@ struct _settings {
 	
 	/* set up druid canceled */
 	int setup_canceled;
+	
+	/* there is no settings.xml file */
+	int first_run;
+	
+	/* widget shadow type */
+	int shadow_type;
+	
+	/* signal id dictionary combo changed */
+	long signal_id;
+	
 };
 
 extern SETTINGS settings;
