@@ -39,12 +39,14 @@
 
 #include "main/sidebar.h"
 #include "main/lists.h"
+#include "main/navbar.h"
 #include "main/settings.h"
 #include "main/sword.h"
-#include "main/url.h"
+//#include "main/tab_struct.h"
+#include "main/url.hh"
 #include "main/xml.h"
 
-#include "backend/sword.h"
+//#include "backend/sword.h"
 #include "backend/sword_main.hh"
 
 
@@ -135,6 +137,7 @@ void main_display_verse_list_in_sidebar(gchar * key, gchar * module_name,
 	GtkTreePath *path;
 	GtkTreeIter iter;	
 	
+	//g_warning("verse_list = %s",verse_list);
 	list_of_verses = g_list_first(list_of_verses);
 	if(list_of_verses) {
 		while(list_of_verses) {
@@ -456,16 +459,30 @@ static void add_books_to_bible(GtkTreeModel * model, GtkTreeIter iter,
 			       const gchar * mod_name)
 {
 	GList *tmp = NULL;
-	gint i;
+	VerseKey key;
+	gint j = 0;
 	GtkTreeIter child_iter;
-
+	gsize bytes_read;
+	gsize bytes_written;
+	GError *error = NULL;
+	gchar *buf = NULL;
+	
 	gtk_tree_store_set(GTK_TREE_STORE(model), &iter,
 			   COL_OPEN_PIXBUF, pixbufs->pixbuf_opened, -1);
 	if (backend->module_has_testament(mod_name, 1)) {
-		tmp = get_list(BOOKS_LIST);
-		for (i = 0; i < 39; i++) {
-			gchar *buf =
-			    (gchar *) (g_list_nth(tmp, i))->data;
+		while(j < key.BMAX[0]) {
+			buf = g_convert((const char *)key.books[0][j].name,
+				     -1,
+				     UTF_8,
+				     OLD_CODESET,
+				     &bytes_read,
+				     &bytes_written,
+				     &error);
+			if(buf == NULL) {
+				g_print ("error: %s\n", error->message);
+				g_error_free (error);
+				continue;
+			}//(gchar *) key.books[0][j].name;
 			gchar *key =
 			    g_strdup_printf("book://%s/%s 1:1",
 					    mod_name, buf);
@@ -482,13 +499,25 @@ static void add_books_to_bible(GtkTreeModel * model, GtkTreeIter iter,
 					   COL_OFFSET, (gchar *) key,
 					   -1);
 			g_free(key);
+			g_free(buf);
+			++j;
 		}
 	}
+	j = 0;
 	if (backend->module_has_testament(mod_name, 2)) {
-		tmp = get_list(BOOKS_LIST);
-		for (i = 39; i < 66; i++) {
-			gchar *buf =
-			    (gchar *) (g_list_nth(tmp, i))->data;
+		while(j < key.BMAX[1]) {
+			buf = g_convert((const char *)key.books[1][j].name,
+				     -1,
+				     UTF_8,
+				     OLD_CODESET,
+				     &bytes_read,
+				     &bytes_written,
+				     &error);
+			if(buf == NULL) {
+				g_print ("error: %s\n", error->message);
+				g_error_free (error);
+				continue;
+			}//(gchar *) key.books[1][j].name;
 			gchar *key =
 			    g_strdup_printf("book://%s/%s 1:1",
 					    mod_name, buf);
@@ -505,6 +534,8 @@ static void add_books_to_bible(GtkTreeModel * model, GtkTreeIter iter,
 					   COL_OFFSET, (gchar *) key,
 					   -1);
 			g_free(key);
+			g_free(buf);
+			++j;
 		}
 	}
 }
@@ -535,7 +566,7 @@ void main_mod_treeview_button_one(GtkTreeModel * model,
 	gchar *key = NULL;
 	gchar *offset = NULL;
 	gint mod_type;
-
+	GtkTreePath *path;
 
 	gtk_tree_model_get(GTK_TREE_MODEL(model), &selected,
 			   2, &cap, 3, &mod, 4, &key, -1);
@@ -543,33 +574,37 @@ void main_mod_treeview_button_one(GtkTreeModel * model,
 		return;
 	if (!g_utf8_collate(cap, _("Parallel View")))
 		gtk_notebook_set_current_page(GTK_NOTEBOOK
-					      (widgets.
-					       notebook_parallel_text),
+					      (widgets.notebook_bible_parallel),
 					      1);
 
 	if (!g_utf8_collate(cap, _("Standard View")))
 		gtk_notebook_set_current_page(GTK_NOTEBOOK
-					      (widgets.
-					       notebook_parallel_text),
+					      (widgets.notebook_bible_parallel),
 					      0);
 
 	if (!g_utf8_collate(cap, _("Commentaries"))) {
 		if (!settings.comm_showing) {
 			settings.comm_showing = TRUE;
-			main_display_commentary(settings.
+			gtk_notebook_set_current_page(GTK_NOTEBOOK
+					      (widgets.notebook_comm_book),
+					      0);
+			/*main_display_commentary(settings.
 						CommWindowModule,
-						settings.currentverse);
+						settings.currentverse);*/
 		}
 	}
 
 	if (!g_utf8_collate(cap, _("General Books"))) {
 		if (settings.comm_showing) {
 			settings.comm_showing = FALSE;
-			offset =
+			gtk_notebook_set_current_page(GTK_NOTEBOOK
+					      (widgets.notebook_comm_book),
+					      1);
+			/*offset =
 			    g_strdup_printf("%lu",
 					    settings.book_offset);
 			main_display_book(settings.book_mod, offset);
-			g_free(offset);
+			g_free(offset);*/
 		}
 	}
 
@@ -580,9 +615,8 @@ void main_mod_treeview_button_one(GtkTreeModel * model,
 	switch (sbtype) {
 	case TEXT_TYPE:
 		gtk_notebook_set_current_page(GTK_NOTEBOOK
-					      (widgets.
-					       notebook_parallel_text),
-					      0);
+					     (widgets.notebook_bible_parallel),
+					     0);
 		if (!gtk_tree_model_iter_has_child
 		    (GTK_TREE_MODEL(model), &selected)
 		    && !key)
@@ -595,13 +629,23 @@ void main_mod_treeview_button_one(GtkTreeModel * model,
 		    (GTK_TREE_MODEL(model), &selected)
 		    && strstr(key, "chapter:"))
 			add_verses_to_chapter(model, selected, key);
+		
 		if (key)
 			main_url_handler(key, TRUE);
-		else
+		else {
+			if(navbar_main.module_name) 
+				g_free(navbar_main.module_name);
+			navbar_main.module_name = g_strdup(mod);
+			main_navbar_fill_book_combo(navbar_main);
 			main_display_bible(mod, settings.currentverse);
+		}
+			
 		break;
 	case COMMENTARY_TYPE:
 	case PERCOM_TYPE:
+		gtk_notebook_set_current_page(GTK_NOTEBOOK
+					(widgets.notebook_comm_book),
+					0);
 		settings.comm_showing = TRUE;
 		main_display_commentary(mod, settings.currentverse);
 		break;
@@ -610,9 +654,15 @@ void main_mod_treeview_button_one(GtkTreeModel * model,
 		break;
 	case BOOK_TYPE:
 		settings.comm_showing = FALSE;
+		gtk_notebook_set_current_page(GTK_NOTEBOOK
+					(widgets.notebook_comm_book),
+					1);
+		backend->set_module(mod);
+		backend->set_treekey(atoi((key) ? key : (gchar *) "0"));
 		main_display_book(mod, (key) ? key : (gchar *) "0");
-		if (!gtk_tree_model_iter_has_child
-		    (GTK_TREE_MODEL(model), &selected)
+		path = gtk_tree_model_get_path(model,&selected);
+		if (!gtk_tree_model_iter_has_child(
+			GTK_TREE_MODEL(model), &selected)
 		    && !key) {
 			add_children_to_tree(model,
 					     selected,
@@ -620,11 +670,16 @@ void main_mod_treeview_button_one(GtkTreeModel * model,
 					     backend->
 					     get_treekey_offset());
 		}
-		if (!gtk_tree_model_iter_has_child(model, &selected)
+		if (!gtk_tree_model_iter_has_child(
+			GTK_TREE_MODEL(model), &selected)
 		    && backend->treekey_has_children(atoi(key))) {
 			add_children_to_tree(model,
 					     selected, mod, atol(key));
 		}
+		gtk_tree_view_expand_row(GTK_TREE_VIEW(sidebar.module_list),
+                                             path,
+                                             FALSE);
+		gtk_tree_path_free(path);
 		break;
 	}
 	if (cap)
@@ -968,40 +1023,4 @@ void main_add_mod_tree_columns(GtkTreeView * tree)
 	gtk_tree_view_column_set_visible(column, FALSE);
 }
 
-
-/******************************************************************************
- * Name
- *   
- *
- * Synopsis
- *   #include "main/sidebar.h"
- *
- *   gboolean (char *mod_name, char *key)
- *
- * Description
- *
- *
- * Return value
- *   gboolean
- */
-
-gboolean main_sidebar_display_dictlex(char *mod_name, char *key)
-{
-	if (settings.showshortcutbar) {
-		gchar *text;
-		/*gtk_option_menu_set_history(GTK_OPTION_MENU
-					    (sidebar.optionmenu1), 4);*/
-		gtk_notebook_set_current_page(GTK_NOTEBOOK
-				      (widgets.notebook_sidebar), 4);
-		text = backend->get_render_text(mod_name, key);
-		if (text) {
-			main_entry_display(sidebar.html_viewer_widget,
-				      mod_name, text, key, TRUE);
-			free(text);
-			return TRUE;
-		}
-	}
-	return FALSE;
-}
-
 /******   end of file   ******/
