@@ -85,6 +85,70 @@ extern gboolean shift_key_presed;
 
 gboolean style_display = TRUE;
 
+/******************************************************************************
+ * Name
+ *   main_save_note
+ *
+ * Synopsis
+ *   #include "main/sword.h"
+ *
+ *   void main_save_note(const gchar * module_name, 
+ *				          const gchar * key_str , 
+ *				          const gchar * note_str )	
+ *
+ * Description
+ *   
+ *
+ * Return value
+ *   void
+ */
+
+void main_save_note(	const gchar * module_name, 
+			const gchar * key_str, 
+			const gchar * note_str )
+{
+#ifdef USE_GTKHTML38
+	backend->set_module_key(module_name, key_str);
+#ifdef DEBUG
+	g_message("note module %s\nnote key %s\nnote text%s",
+				module_name,
+				key_str,
+				note_str);
+#endif
+	backend->save_entry(note_str);
+#endif
+}
+
+/******************************************************************************
+ * Name
+ *   main_delete_note
+ *
+ * Synopsis
+ *   #include "main/sword.h"
+ *
+ *   void main_delete_note(DIALOG_DATA * d)	
+ *
+ * Description
+ *   
+ *
+ * Return value
+ *   void
+ */
+
+void main_delete_note(	const gchar * module_name, 
+								const gchar * key_str)
+{
+#ifdef USE_GTKHTML38
+	backend->set_module_key(module_name, key_str);
+#ifdef DEBUG
+	g_message("note module %s\nnote key %s\n",
+				module_name,
+				key_str);
+#endif
+	backend->delete_entry();
+#endif	
+}
+
 	
 /******************************************************************************
  * Name
@@ -1117,6 +1181,27 @@ char *main_get_striptext(char *module_name, char *key)
 }
 
 
+/******************************************************************************
+ * Name
+ *   main_get_striptext
+ *
+ * Synopsis
+ *   #include "main/sword.h"
+ *
+ *   char *main_get_striptext(char *module_name, char *key)	
+ *
+ * Description
+ *   
+ *
+ * Return value
+ *   char *
+ */
+
+char *main_get_striptext_from_string(char *module_name, char *string)
+{
+	return backend->get_strip_text_from_string(module_name, string);
+}
+
 /******************************************************************************
  * Name
  *   main_get_rendered_text
